@@ -24,7 +24,12 @@ define!({
     pub struct SimpleBlock {
         pub span: Span,
         pub name: char,
-        pub value: Vec<Value>,
+        pub value: Vec<ComponentValue>,
+    }
+
+    pub enum ComponentValue {
+        Value(Value),
+        DeclarationBlockItem(DeclarationBlockItem),
     }
 
     pub struct Ident {
@@ -77,12 +82,7 @@ define!({
     pub struct QualifiedRule {
         pub span: Span,
         pub prelude: SelectorList,
-        pub block: Block,
-    }
-
-    pub struct Block {
-        pub span: Span,
-        pub value: Vec<DeclarationBlockItem>,
+        pub block: SimpleBlock,
     }
 
     pub enum DeclarationBlockItem {
@@ -435,7 +435,7 @@ define!({
 
     pub struct FontFaceRule {
         pub span: Span,
-        pub block: Block,
+        pub block: SimpleBlock,
     }
 
     pub enum NamespaceUri {
@@ -451,7 +451,7 @@ define!({
 
     pub struct ViewportRule {
         pub span: Span,
-        pub block: Block,
+        pub block: SimpleBlock,
     }
 
     pub enum AtRuleName {
@@ -491,7 +491,7 @@ define!({
     pub struct KeyframeBlock {
         pub span: Span,
         pub prelude: Vec<KeyframeSelector>,
-        pub block: Block,
+        pub block: SimpleBlock,
     }
 
     pub enum KeyframeSelector {
